@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 	"log"
+	"slices"
 	"time"
 
 	"github.com/gdamore/tcell/v2"
@@ -45,17 +46,17 @@ func (root *Root) draw(ctx context.Context) {
 	}
 
 	root.drawStatus()
-	root.Show()
+	root.Screen.Show()
 }
 
 // drawBody draws body.
 func (root *Root) drawBody(lX int, lN int) (int, int) {
 	m := root.Doc
 
-	markStyleWidth := min(root.scr.vWidth, root.Doc.general.MarkStyleWidth)
+	markStyleWidth := min(root.scr.vWidth, root.Doc.MarkStyleWidth)
 
 	wrapNum := m.numOfWrap(lX, lN)
-	for y := m.headerHeight; y < root.scr.vHeight-statusLine; y++ {
+	for y := m.headerHeight; y < root.scr.vHeight-root.scr.statusLineHeight; y++ {
 		lineC, ok := root.scr.lines[lN]
 		if !ok {
 			log.Panicf("line is not found %d", lN)
@@ -108,7 +109,7 @@ func (root *Root) drawHeader() {
 		lX, lN = root.drawLine(y, lX, lN, lineC)
 		root.drawVerticalHeader(y, wrapNum, lineC)
 		// header style.
-		root.applyStyleToLine(y, root.StyleHeader)
+		root.applyStyleToLine(y, m.Style.Header)
 
 		wrapNum++
 		if lX == 0 {
@@ -116,7 +117,7 @@ func (root *Root) drawHeader() {
 		}
 	}
 	if root.scr.headerEnd > 0 {
-		root.applyStyleToLine(m.headerHeight-1, root.StyleHeaderBorder)
+		root.applyStyleToLine(m.headerHeight-1, m.Style.HeaderBorder)
 	}
 }
 
@@ -138,11 +139,11 @@ func (root *Root) drawSectionHeader() {
 
 		nextLX, nextLN := root.drawLine(y, lX, lN, lineC)
 		// section header style.
-		root.applyStyleToLine(y, root.StyleSectionLine)
+		root.applyStyleToLine(y, m.Style.SectionLine)
 
 		root.drawVerticalHeader(y, wrapNum, lineC)
 		// markstyle is displayed above the section header.
-		markStyleWidth := min(root.scr.vWidth, m.general.MarkStyleWidth)
+		markStyleWidth := min(root.scr.vWidth, m.MarkStyleWidth)
 		root.applyMarkStyle(lN, y, markStyleWidth)
 		// Underline search lines when they overlap in section headers.
 		if lN == m.lastSearchLN {
@@ -157,7 +158,7 @@ func (root *Root) drawSectionHeader() {
 		lX = nextLX
 		lN = nextLN
 	}
-	root.applyStyleToLine(m.headerHeight+m.sectionHeaderHeight-1, root.StyleSectionHeaderBorder)
+	root.applyStyleToLine(m.headerHeight+m.sectionHeaderHeight-1, m.Style.SectionHeaderBorder)
 }
 
 // drawRuler draws the ruler.
@@ -172,8 +173,8 @@ func (root *Root) drawRuler() {
 		startX = root.scr.startX - root.Doc.x
 	}
 
-	style := applyStyle(defaultStyle, root.StyleRuler)
-	for x := 0; x < root.scr.vWidth; x++ {
+	style := applyStyle(defaultStyle, root.Doc.Style.Ruler)
+	for x := range root.scr.vWidth {
 		n := x - startX + 1
 		if n < 0 {
 			continue
@@ -201,7 +202,7 @@ func (root *Root) drawLine(y int, lX int, lN int, lineC LineC) (int, int) {
 // drawWrapLine wraps and draws the contents and returns the next drawing position.
 func (root *Root) drawWrapLine(y int, lX int, lN int, lineC LineC) (int, int) {
 	if lX < 0 {
-		log.Printf("Illegal lX:%d", lX)
+		log.Printf("Illegal lX: %d\n", lX)
 		return 0, 0
 	}
 	screen := root.Screen
@@ -266,18 +267,18 @@ func (root *Root) drawVerticalHeader(y int, wrapNum int, lineC LineC) {
 	}
 
 	screen := root.Screen
-	for n := 0; n < widthVH; n++ {
+	for n := range widthVH {
 		c := DefaultContent
 		if n < len(lineC.lc) {
 			c = lineC.lc[n]
 		}
-		style := applyStyle(c.style, root.StyleVerticalHeader)
+		style := applyStyle(c.style, root.Doc.Style.VerticalHeader)
 		if n == widthVH-2 && c.width == 2 {
-			style = applyStyle(defaultStyle, root.StyleVerticalHeaderBorder)
+			style = applyStyle(defaultStyle, root.Doc.Style.VerticalHeaderBorder)
 			screen.SetContent(root.scr.startX+n, y, c.mainc, c.combc, style)
 			return
 		} else if n == widthVH-1 {
-			style = applyStyle(defaultStyle, root.StyleVerticalHeaderBorder)
+			style = applyStyle(defaultStyle, root.Doc.Style.VerticalHeaderBorder)
 			screen.SetContent(root.scr.startX+n, y, c.mainc, c.combc, style)
 			return
 		}
@@ -313,7 +314,7 @@ func (root *Root) blankLineNumber(y int) {
 	if root.scr.startX <= 0 {
 		return
 	}
-	for x := 0; x < root.scr.startX-1; x++ {
+	for x := range root.scr.startX {
 		root.Screen.SetContent(x, y, ' ', nil, defaultStyle)
 	}
 }
@@ -342,9 +343,9 @@ func (root *Root) drawLineNumber(lN int, y int, valid bool) {
 	// Line numbers start at 1 except for skip and header lines.
 	number = number - m.firstLine() + 1
 
-	style := applyStyle(defaultStyle, root.StyleLineNumber)
+	style := applyStyle(defaultStyle, m.Style.LineNumber)
 	numC := []rune(fmt.Sprintf("%*d", root.scr.startX-1, number))
-	for i := 0; i < len(numC); i++ {
+	for i := range numC {
 		root.Screen.SetContent(i, y, numC[i], nil, style)
 	}
 	root.Screen.SetContent(len(numC), y, ' ', nil, defaultStyle)
@@ -377,7 +378,7 @@ func (root *Root) coordinatesStyle(lN int, y int) {
 		root.applyStyleToAlternate(lN, y)
 	}
 	if root.Doc.jumpTargetHeight != 0 && root.Doc.headerHeight+root.Doc.jumpTargetHeight == y {
-		root.applyStyleToLine(y, root.StyleJumpTargetLine)
+		root.applyStyleToLine(y, root.Doc.Style.JumpTargetLine)
 	}
 }
 
@@ -386,7 +387,7 @@ func (root *Root) applyStyleToAlternate(lN int, y int) {
 	if (lN)%2 == 0 {
 		return
 	}
-	root.applyStyleToLine(y, root.StyleAlternate)
+	root.applyStyleToLine(y, root.Doc.Style.Alternate)
 }
 
 // applyStyleToLine applies the style from the left edge to the right edge of the physical line.
@@ -398,16 +399,16 @@ func (root *Root) applyStyleToLine(y int, s OVStyle) {
 // applyMarkStyle applies the style from the left edge to the specified width.
 func (root *Root) applyMarkStyle(lN int, y int, width int) {
 	m := root.Doc
-	if !contains(m.marked, lN) {
+	if !slices.Contains(m.marked, lN) {
 		return
 	}
-	root.applyStyleToRange(y, root.StyleMarkLine, 0, width)
+	root.applyStyleToRange(y, m.Style.MarkLine, 0, width)
 }
 
 // applyStyleToRange applies the style from the start to the end of the physical line.
 func (root *Root) applyStyleToRange(y int, s OVStyle, start int, end int) {
 	for x := start; x < end; x++ {
-		mainc, combc, style, width := root.GetContent(x, y)
+		mainc, combc, style, width := root.Screen.GetContent(x, y)
 		newStyle := applyStyle(style, s)
 		if style != newStyle {
 			root.Screen.SetContent(x, y, mainc, combc, newStyle)
@@ -429,7 +430,7 @@ func (root *Root) sectionLineHighlight(y int, line LineC) {
 	if line.sectionNm <= 0 || line.sectionNm > root.Doc.SectionHeaderNum {
 		return
 	}
-	root.applyStyleToLine(y, root.StyleSectionLine)
+	root.applyStyleToLine(y, root.Doc.Style.SectionLine)
 }
 
 // hideOtherSection hides other sections.
@@ -492,8 +493,8 @@ func (root *Root) notifyEOFReached(m *Document) {
 
 // notify notifies by beeping and flashing the screen the specified number of times.
 func (root *Root) notify(count int) {
-	for i := 0; i < count; i++ {
-		root.Screen.Beep()
+	for range count {
+		_ = root.Screen.Beep()
 		root.flash()
 	}
 }
