@@ -1,17 +1,18 @@
 package oviewer
 
 import (
+	"context"
 	"strconv"
 
 	"github.com/gdamore/tcell/v2"
 )
 
-// setTabWidthMode sets the inputMode to TabWidth.
-func (root *Root) setTabWidthMode() {
+// inputTabWidth sets the inputMode to TabWidth.
+func (root *Root) inputTabWidth(context.Context) {
 	input := root.input
 	input.reset()
-	input.TabWidthCandidate.toLast(strconv.Itoa(root.Doc.TabWidth))
-	input.Event = newTabWidthEvent(input.TabWidthCandidate)
+	input.Candidate[TabWidth].toLast(strconv.Itoa(root.Doc.TabWidth))
+	input.Event = newTabWidthEvent(input.Candidate[TabWidth])
 }
 
 // tabWidthCandidate returns the candidate to set to default.
